import sys, string

from xml.dom import minidom, Node


# Funkce pro vložení složeného elementu <polozka>
# <polozka> obsahuje atribut "kod" (code) a vnořené elementy <nazev> a <mnozstvi>
# <nazev> je jednoduchý element obsahující pouze hodnotu (name)
# <mnozstvi> obsahuje atributy "cena" (price), "jednotka" (unit) a hodnotu (num)
# Parametry funkce:
# 	doc - stromová struktura XML dokumentu
# 	parentNode - rodičovský uzel, kterému se vkládá potomek
# 	name - hodnota elementu <nazev>
# 	price - hodnota atributu "cena" elementu <mnozstvi>
# 	unit - hodnota atributu "jednotka" elementu <mnozstvi>
# 	num - hodnota elementu <mnozstvi>
def addPolozka(doc, parentNode, code, name, price, unit, num):
    
    tmpNode = doc.createTextNode("\n		")                 # Pomocný TEXT_NODE pro spravné odsazení elementu
    parentNode.appendChild(tmpNode)                                # Vložení elementu do seznamu potomků uzlu parentNode
    
    polozka = doc.createElement("polozka")                         # Vytvoření nového elementu <polozka>
    tmpPolozka1 = doc.createTextNode("\n			") # Pomocný TEXT_NODE pro spravné odsazení elementu
    polozka.appendChild(tmpPolozka1)                               # Vložení elementu do seznamu potomků uzlu 'polozka'
    polozka.setAttribute("kod", code)                              # Vytvoření atributu "kod" elementu <polozka> a nastavení jeho hodnoty
    
    nazev = doc.createElement("nazev")                             # Vytvoření nového elementu <nazev>
    textNazev = doc.createTextNode(name)                           # Nový TEXT_NODE obsahující hodnotu elementu <nazev>
    nazev.appendChild(textNazev)                                   # Vložení elementu 'textNazev' do seznamu potomků uzlu 'nazev'
    polozka.appendChild(nazev)                                     # Vložení elementu 'nazev' do seznamu potomků uzlu 'polozka'
    
    tmpPolozka2 = doc.createTextNode("\n			") # Pomocný TEXT_NODE pro spravné odsazení elementu
    polozka.appendChild(tmpPolozka2)                               # Vložení elementu do seznamu potomků uzlu 'polozka'
    
    mnozstvi = doc.createElement("mnozstvi")                       # Vytvoření nového elementu <mnozstvi>
    mnozstvi.setAttribute("cena", price)                           # Vytvoření atributu "cena" elementu <mnozstvi> a nastavení jeho hodnoty
    mnozstvi.setAttribute("jednotka", unit)                        # Vytvoření atributu "jednotka" elementu <mnozstvi> a nastavení jeho hodnoty
    textMnozstvi = doc.createTextNode(num)                         # Nový TEXT_NODE obsahující hodnotu elementu <mnozstvi>
    mnozstvi.appendChild(textMnozstvi)                             # Vložení elementu 'textMnozstvi' do seznamu potomků uzlu 'mnozstvi'
    polozka.appendChild(mnozstvi)                                  # Vložení elementu 'mnozstvi' do seznamu potomků uzlu 'polozka'
    
    tmpPolozka3 = doc.createTextNode("\n		")         # Pomocný TEXT_NODE pro spravné odsazení elementu
    polozka.appendChild(tmpPolozka3)                               # Vložení elementu do seznamu potomků uzlu 'polozka'
    
    parentNode.appendChild(polozka)                                # Vložení nového elementu 'polozka' do seznamu potomků rodičovského uzlu


# Funkce pro průchod stromem využívající generátory  
def walkTree(node):
    if node.nodeType == Node.ELEMENT_NODE:
        yield node
        for child in node.childNodes:
            for n1 in walkTree(child):
                yield n1

# Funkce pro běh programu, parametr je jméno XML souboru
def run(inFileName):
    
    outFile = sys.stdout                                              # Standardní výstup
    doc = minidom.parse(inFileName)                                   # Parsování dokumentu a vytvoření stromové struktury
    rootNode = doc.documentElement                                    # Nastavení kořenestromu na documentElement

    for node in walkTree(rootNode):                                   # Průchod stromovou strukturou
        if node.nodeName == "ovoce":                                  # Vložení nové položky do elementu <ovoce>
            tmpOvoce1 = doc.createTextNode("	")                    # Pomocný TEXT_NODE pro spravné odsazení elementu
            node.appendChild(tmpOvoce1)
            addPolozka(doc, node, "0056", "banany", "25", "kg", "15") # Volání funkce pro vložení nové položky
            tmpOvoce2 = doc.createTextNode("\n	")                    # Pomocný TEXT_NODE pro spravné odsazení elementu
            node.appendChild(tmpOvoce2)
        elif node.nodeName == "zelenina":                             # Vložení nových položek do elementu <zelenina>
            tmpZelenina1 = doc.createTextNode("	")                    # Pomocný TEXT_NODE pro spravné odsazení elementu
            node.appendChild(tmpZelenina1)
            addPolozka(doc, node, "1090", "kedlubna", "8", "ks", "5") # Volání funkce pro vložení nové položky
            addPolozka(doc, node, "1085", "mrkev", "20", "kg", "10")
            tmpZelenina2 = doc.createTextNode("\n	")            # Pomocný TEXT_NODE pro spravné odsazení elementu
            node.appendChild(tmpZelenina2)
#            break

    print(doc.toprettyxml(indent = '   '))                            # Tisk stromové struktury
    file_xml = open("jidlo_new.xml", "w")                             # Vytvoření nového souboru pro zápis upraveného XML dokumentu
    doc.writexml(file_xml)                                            # Zápis dat do souboru


# Funkce pro test počtů vstupních parametrů
def main():
    args = sys.argv[1:]

    if len(args) != 1:
        print('Pro spuštění zadejte: python dom_add.py jidlo.xml')
        sys.exit(-1)

    run(args[0])

main()
