"""
SAX zpracování dokumentu:
Program zjistí jména všech druhů ovoce, které je prodáváno na kg.
Data se čtou z XML dokumentu, který je zadán jako parametr skriptu.
Jména se ukládají do seznamu a tisknou se na standardní výstup.
"""

import sys, string

# Import modulu pro tvorbu stromové struktury a uzlů stromu
from xml.dom import minidom, Node

nameList = []		                                     # Seznam jmen

# Funkce pro běh programu
def run(inFileName):    
    outFile = sys.stdout                                     # Standardní vystup    
    doc = minidom.parse(inFileName)                          # Parsování dokumentu a vytvoření stromové struktury    
    rootNode = doc.documentElement                           # Nastavení kořene stromu na documentElement    
    ovoce = rootNode.getElementsByTagName("ovoce")           # Vytvoření seznamu elementu <ovoce>

    if len(ovoce) == 1:                                      # Test zda je jen jeden        
        items = ovoce[0].getElementsByTagName("polozka")     # Vytvoření seznamu elementů <polozka>        
        for item in items:                                   # Průchod seznamem
            for child in item.childNodes:                    # Průchod seznamem bezprostředních následovníků elementu <polozka>
                if child.nodeName == "nazev":                # Pokud se jedná o element <nazev>
                    ovoceName = ''                           # vyprázdni proměnnou pro uchování názvu ovoce
                    for node in child.childNodes:            # a projdi jeho bezprostřední následovníky elementu <nazev>
                        if node.nodeType == Node.TEXT_NODE:  # a uzly typu TEXT_NODE skládej do připravené proměnné pro název ovoce
                            ovoceName = ovoceName + node.nodeValue  
                elif child.nodeName == "mnozstvi":           # Pokud se jedná o element <monozstvi>
                    attrs = child.attributes
                    unit = attrs.get("jednotka").nodeValue   # najdi ve slovníku atributů atribut jednotka
                    if unit == "kg":                         # a pokud je hodnota atributu = kg
                        nameList.append(ovoceName)           # ulož načtený název ovoce do připraveného seznamu
    else:
        outFile.write("Ovoce není objednané!\n")

    printList(outFile, nameList)
	
def printList(outfile, nameList):                            # Funkce pro tisk seznamu
    outfile.write("V objednávce je {0:d} druhů ovoce:\n".format(len(nameList)))
    for name in nameList:
        outfile.write(" {0:s}\n".format(name))

def main():                                                  # Funkce pro test počtů vstupních parametrů
    args = sys.argv[1:]

    if len(args) != 1:
        print('Pro spuštění zadejte: python dom_atributy.py jidlo.xml')
        sys.exit(-1)

    run(args[0])

main()
