"""
SAX zpracování dokumentu:
Program zjistí jména všech druhů ovoce z XML dokumentu, který je zadán jako parametr skriptu
a ukládá je do seznamu, který vytiskne na standardní výstup.
"""

import sys

# Import sax handleru a parseru
from xml.sax import handler, make_parser

# Definice nové třídy odděděné od ContentHandler
class MySaxDocumentHandler(handler.ContentHandler):
    
    def __init__(self, outfile):             # Konstruktor třídy
        self.outfile = outfile               # Standardní výstup
        self.inOvoce = False                 # Indikátor stavu
        self.inName = False                  # Indikátor stavu
        self.ovoce = ''                      # Jméno ovoce
        self.nameList = []                   # Seznam jmen
	
    def get_nameList(self):                  # Funkce pro vrácení seznamu jmen
        return self.nameList
    	
    def set_nameList(self, nameList):        # Funkce pro nastavení seznamu
        self.nameList = nameList
        	
    def endDocument(self):                   # Překrytí metody endDocument(self)
        self.outfile.write("V objednávce je {0:d} druhů ovoce:\n".format(len(self.nameList)))
        
    def startElement(self, name, attrs):     # Překrytí metody startElement(self)
        if name == 'ovoce':
            self.inOvoce = True
        elif name == 'nazev':
            self.inName = True
            self.ovoce = ''            

    def endElement(self, name):              # Překrytí metody endElement(self, name)
        if name == 'nazev' and self.inOvoce: # Končí element <nazev> a současně jsme v elementu ovoce                        
            self.nameList.append(self.ovoce)        
            self.inName = False
        elif name == 'ovoce':                # Končí element <ovoce>
            self.inOvoce = False
	    	
    def characters(self, chrs):              # Překrytí metody characters(self, chrs)
        if self.inOvoce and self.inName:
            self.ovoce = self.ovoce + chrs


def printList(outfile, nameList):               # Funkce pro tisk seznamu
    for name in nameList:
        outfile.write(" {0:s}\n".format(name))

			
def run(inFileName):                            # Funkce pro běh 			
    outFile = sys.stdout    
    handler = MySaxDocumentHandler(outFile)     # Vytvoření instance handleru    
    parser = make_parser()                      # Vytvoření instance parseru    
    parser.setContentHandler(handler)           # Nastavení handleru     
    inFile = open(inFileName, 'r')              # Otevření souboru pro čtení    
    parser.parse(inFile)                        # Parsování souboru    
    printList(outFile, handler.get_nameList())  # Volání funkce pro tisk načteného seznamu
    inFile.close()                              # Zatvření souboru

def main():                                     # Funkce pro test počtu vstupních parametrů
    args = sys.argv[1:]				# Seznam parametrů
    
    if len(args) != 1:
        print('Pro spuštění zadejte: python sax_elementy.py jidlo.xml')
        sys.exit(-1)	
    
    run(args[0])                               # Volání funkce pro běh programu

main()
